@@ -27,6 +27,7 @@ License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 #include "fullscreen_shell.h"
 #include "idle.h"
 #include "idleinhibit.h"
+#include "remote_access.h"
 #include "logging_p.h"
 #include "outputconfiguration.h"
 #include "outputmanagement.h"
@@ -53,6 +54,7 @@ License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 #include "xdgforeign_v2.h"
 #include "appmenu.h"
 #include "server_decoration_palette.h"
+#include "xdgoutput.h"
 // Qt
 #include <QDebug>
 // wayland
@@ -62,6 +64,7 @@ License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 #include <wayland-plasma-window-management-client-protocol.h>
 #include <wayland-idle-client-protocol.h>
 #include <wayland-idle-inhibit-unstable-v1-client-protocol.h>
+#include <wayland-remote-access-client-protocol.h>
 #include <wayland-fake-input-client-protocol.h>
 #include <wayland-shadow-client-protocol.h>
 #include <wayland-output-management-client-protocol.h>
@@ -73,14 +76,16 @@ License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 #include <wayland-server-decoration-client-protocol.h>
 #include <wayland-text-input-v0-client-protocol.h>
 #include <wayland-text-input-v2-client-protocol.h>
-#include <wayland-xdg-shell-v5-client-protocol.h>
+#include "../compat/wayland-xdg-shell-v5-client-protocol.h"
 #include <wayland-xdg-shell-v6-client-protocol.h>
+#include <wayland-xdg-shell-client-protocol.h>
 #include <wayland-relativepointer-unstable-v1-client-protocol.h>
 #include <wayland-pointer-gestures-unstable-v1-client-protocol.h>
 #include <wayland-pointer-constraints-unstable-v1-client-protocol.h>
 #include <wayland-xdg-foreign-unstable-v2-client-protocol.h>
 #include <wayland-appmenu-client-protocol.h>
 #include <wayland-server-decoration-palette-client-protocol.h>
+#include <wayland-xdg-output-unstable-v1-client-protocol.h>
 
 /*****
  * How to add another interface:
@@ -138,7 +143,7 @@ static const QMap<Registry::Interface, SuppertedInterfaceData> s_interfaces = {
         &Registry::shmRemoved
     }},
     {Registry::Interface::Seat, {
-        4,
+        5,
         QByteArrayLiteral("wl_seat"),
         &wl_seat_interface,
         &Registry::seatAnnounced,
@@ -159,14 +164,14 @@ static const QMap<Registry::Interface, SuppertedInterfaceData> s_interfaces = {
         &Registry::subCompositorRemoved
     }},
     {Registry::Interface::PlasmaShell, {
-        4,
+        5,
         QByteArrayLiteral("org_kde_plasma_shell"),
         &org_kde_plasma_shell_interface,
         &Registry::plasmaShellAnnounced,
         &Registry::plasmaShellRemoved
     }},
     {Registry::Interface::PlasmaWindowManagement, {
-        7,
+        9,
         QByteArrayLiteral("org_kde_plasma_window_management"),
         &org_kde_plasma_window_management_interface,
         &Registry::plasmaWindowManagementAnnounced,
@@ -179,6 +184,13 @@ static const QMap<Registry::Interface, SuppertedInterfaceData> s_interfaces = {
         &Registry::idleAnnounced,
         &Registry::idleRemoved
     }},
+    {Registry::Interface::RemoteAccessManager, {
+        1,
+        QByteArrayLiteral("org_kde_kwin_remote_access_manager"),
+        &org_kde_kwin_remote_access_manager_interface,
+        &Registry::remoteAccessManagerAnnounced,
+        &Registry::remoteAccessManagerRemoved
+    }},
     {Registry::Interface::FakeInput, {
         2,
         QByteArrayLiteral("org_kde_kwin_fake_input"),
@@ -187,14 +199,14 @@ static const QMap<Registry::Interface, SuppertedInterfaceData> s_interfaces = {
         &Registry::fakeInputRemoved
     }},
     {Registry::Interface::OutputManagement, {
-        1,
+        2,
         QByteArrayLiteral("org_kde_kwin_outputmanagement"),
         &org_kde_kwin_outputmanagement_interface,
         &Registry::outputManagementAnnounced,
         &Registry::outputManagementRemoved
     }},
     {Registry::Interface::OutputDevice, {
-        1,
+        2,
         QByteArrayLiteral("org_kde_kwin_outputdevice"),
         &org_kde_kwin_outputdevice_interface,
         &Registry::outputDeviceAnnounced,
@@ -266,7 +278,7 @@ static const QMap<Registry::Interface, SuppertedInterfaceData> s_interfaces = {
     {Registry::Interface::XdgShellUnstableV5, {
         1,
         QByteArrayLiteral("xdg_shell"),
-        &xdg_shell_interface,
+        &zxdg_shell_v5_interface,
         &Registry::xdgShellUnstableV5Announced,
         &Registry::xdgShellUnstableV5Removed
     }},
@@ -332,6 +344,20 @@ static const QMap<Registry::Interface, SuppertedInterfaceData> s_interfaces = {
         &org_kde_kwin_server_decoration_palette_manager_interface,
         &Registry::serverSideDecorationPaletteManagerAnnounced,
         &Registry::serverSideDecorationPaletteManagerRemoved
+    }},
+    {Registry::Interface::XdgOutputUnstableV1, {
+        1,
+        QByteArrayLiteral("zxdg_output_manager_v1"),
+        &zxdg_output_manager_v1_interface,
+        &Registry::xdgOutputAnnounced,
+        &Registry::xdgOutputRemoved
+    }},
+    {Registry::Interface::XdgShellStable, {
+        1,
+        QByteArrayLiteral("xdg_wm_base"),
+        &xdg_wm_base_interface,
+        &Registry::xdgShellStableAnnounced,
+        &Registry::xdgShellStableRemoved
     }}
 };
 
@@ -622,6 +648,7 @@ BIND(DataDeviceManager, wl_data_device_manager)
 BIND(PlasmaShell, org_kde_plasma_shell)
 BIND(PlasmaWindowManagement, org_kde_plasma_window_management)
 BIND(Idle, org_kde_kwin_idle)
+BIND(RemoteAccessManager, org_kde_kwin_remote_access_manager)
 BIND(FakeInput, org_kde_kwin_fake_input)
 BIND(OutputManagement, org_kde_kwin_outputmanagement)
 BIND(OutputDevice, org_kde_kwin_outputdevice)
@@ -630,6 +657,7 @@ BIND(TextInputManagerUnstableV0, wl_text_input_manager)
 BIND(TextInputManagerUnstableV2, zwp_text_input_manager_v2)
 BIND(XdgShellUnstableV5, xdg_shell)
 BIND(XdgShellUnstableV6, zxdg_shell_v6)
+BIND(XdgShellStable, xdg_wm_base)
 BIND(RelativePointerManagerUnstableV1, zwp_relative_pointer_manager_v1)
 BIND(PointerGesturesUnstableV1, zwp_pointer_gestures_v1)
 BIND(PointerConstraintsUnstableV1, zwp_pointer_constraints_v1)
@@ -643,6 +671,7 @@ BIND2(SlideManager, Slide, org_kde_kwin_slide_manager)
 BIND2(DpmsManager, Dpms, org_kde_kwin_dpms_manager)
 BIND2(AppMenuManager, AppMenu, org_kde_kwin_appmenu_manager)
 BIND2(ServerSideDecorationPaletteManager, ServerSideDecorationPalette, org_kde_kwin_server_decoration_palette_manager)
+BIND(XdgOutputUnstableV1, zxdg_output_manager_v1)
 
 #undef BIND
 #undef BIND2
@@ -682,6 +711,7 @@ CREATE(DataDeviceManager)
 CREATE(PlasmaShell)
 CREATE(PlasmaWindowManagement)
 CREATE(Idle)
+CREATE(RemoteAccessManager)
 CREATE(FakeInput)
 CREATE(OutputManagement)
 CREATE(OutputDevice)
@@ -729,6 +759,8 @@ XdgShell *Registry::createXdgShell(quint32 name, quint32 version, QObject *paren
         return d->create<XdgShellUnstableV5>(name, version, parent, &Registry::bindXdgShellUnstableV5);
     case Interface::XdgShellUnstableV6:
         return d->create<XdgShellUnstableV6>(name, version, parent, &Registry::bindXdgShellUnstableV6);
+    case Interface::XdgShellStable:
+        return d->create<XdgShellStable>(name, version, parent, &Registry::bindXdgShellStable);
     default:
         return nullptr;
     }
@@ -774,6 +806,16 @@ IdleInhibitManager *Registry::createIdleInhibitManager(quint32 name, quint32 ver
     }
 }
 
+XdgOutputManager *Registry::createXdgOutputManager(quint32 name, quint32 version, QObject *parent)
+{
+    switch(d->interfaceForName(name)) {
+    case Interface::XdgOutputUnstableV1:
+        return d->create<XdgOutputManager>(name, version, parent, &Registry::bindXdgOutputUnstableV1);
+    default:
+        return nullptr;
+    }
+}
+
 namespace {
 static const wl_interface *wlInterface(Registry::Interface interface)
 {
